aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/analysis/test
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/analysis/test')
-rw-r--r--src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java b/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
index cc483f6ab6..44ae134d9d 100644
--- a/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
+++ b/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
@@ -16,9 +16,11 @@ package com.google.devtools.build.lib.analysis.test;
import com.google.devtools.build.lib.actions.ActionContext;
import com.google.devtools.build.lib.actions.ActionExecutionContext;
import com.google.devtools.build.lib.actions.ExecException;
+import com.google.devtools.build.lib.actions.SpawnResult;
import com.google.devtools.build.lib.vfs.Path;
import com.google.devtools.build.lib.view.test.TestStatus.TestResultData;
import java.io.IOException;
+import java.util.Set;
/**
* A context for the execution of test actions ({@link TestRunnerAction}).
@@ -26,11 +28,13 @@ import java.io.IOException;
public interface TestActionContext extends ActionContext {
/**
* Executes the test command, directing standard out / err to {@code outErr}. The status of
* the test should be communicated by posting a {@link TestResult} object to the eventbus.
*/
- void exec(TestRunnerAction action,
- ActionExecutionContext actionExecutionContext) throws ExecException, InterruptedException;
+ Set<SpawnResult> exec(TestRunnerAction action, ActionExecutionContext actionExecutionContext)
+ throws ExecException, InterruptedException;
/**
* Creates a cached test result.
@@ -26,11 +28,13 @@ import java.io.IOException;
public interface TestActionContext extends ActionContext {
/**
- * Executes the test command, directing standard out / err to {@code outErr}. The status of
- * the test should be communicated by posting a {@link TestResult} object to the eventbus.
+ * Executes the test command, directing standard out / err to {@code outErr}. The status of the
+ * test should be communicated by posting a {@link TestResult} object to the eventbus.
+ *
+ * @return a set of SpawnResults created during execution of the test command, if any
*/